@@ -223,7 +223,19 @@ if __name__ == '__main__':
       from zebrazoom.dataAnalysis.createCustomDataStructure.createDistanceBetweenFramesExcelFile import createDistanceBetweenFramesExcelFile
       createDistanceBetweenFramesExcelFile(paths.getDefaultZZoutputFolder(), sys.argv) # fps, pixelSize
       
-
+    elif sys.argv[1] == "filterLatencyAndMergeBoutsInSameTrials":
+      
+      nameOfExperiment        = sys.argv[2]
+      minFrameNumberBoutStart = int(sys.argv[3])
+      maxFrameNumberBoutStart = int(sys.argv[4])
+      if len(sys.argv) > 5:
+        calculationMethod = sys.argv[5] # Should be equal to 'mean' or 'median'
+      else:
+        calculationMethod = 'median'
+      dropDuplicates = int(sys.argv[6]) if len(sys.argv) > 6 else 0
+      from zebrazoom.dataAnalysis.createCustomDataStructure.filterLatencyAndMergeBoutsInSameTrials import filterLatencyAndMergeBoutsInSameTrials
+      filterLatencyAndMergeBoutsInSameTrials(nameOfExperiment, minFrameNumberBoutStart, maxFrameNumberBoutStart, calculationMethod, dropDuplicates)
+      
     elif sys.argv[1] == "otherScripts":
 
       if sys.argv[2] == "launchActiveLearning":
