@@ -171,19 +171,23 @@ def rectangularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
 
 
 @util.addToHistory
-def homegeneousWellsLayout(self, controller, nbRowsOfWells, nbWellsPerRows):
+def homegeneousWellsLayout(self, controller, nbRowsOfWells, nbWellsPerRows, detectBouts):
 
   self.configFile = {"trackingMethod": "fastCenterOfMassTracking_KNNbackgroundSubtraction", "nbAnimalsPerWell": 1, "nbWells": 8, "nbRowsOfWells": 2, "nbWellsPerRows": 4, "groupOfMultipleSameSizeAndShapeEquallySpacedWells": 1, "postProcessMultipleTrajectories": 0, "trackingPointSizeDisplay": 3, "extractAdvanceZebraParameters": 0,  "validationVideoPlotHeading": 0, "trackTail": 0, "freqAlgoPosFollow": 100, "fasterMultiprocessing": 1, "copyOriginalVideoToOutputFolderForValidation": 0, "backgroundSubtractorKNN": 1, "boutsMinNbFrames": 0, "addOneFrameAtTheEndForBoutDetection": 1, "fillGapFrameNb": 0} # "postProcessMultipleTrajectories": 1, "postProcessRemoveLowProbabilityDetection" : 1, "postProcessLowProbabilityDetectionPercentOfMaximum" : 0.2
 
   self.configFile["nbWells"] = int(nbRowsOfWells) * int(nbWellsPerRows)
   self.configFile["nbRowsOfWells"] = int(nbRowsOfWells)
   self.configFile["nbWellsPerRows"] = int(nbWellsPerRows)
+  self.configFile["noBoutsDetection"] = int(not detectBouts)
 
-  controller.show_frame("FinishConfig")
+  if detectBouts:
+    controller.calculateBackgroundFreelySwim(controller, 0, boutDetectionsOnly=True)
+  else:
+    controller.show_frame("FinishConfig")
 
 
 @util.addToHistory
-def morePreciseFastScreen(self, controller, nbRowsOfWells, nbWellsPerRows):
+def morePreciseFastScreen(self, controller, nbRowsOfWells, nbWellsPerRows, detectBouts):
 
   # The gaussian image filtering should be added here in the future
   self.configFile = {"trackingMethod": "fastCenterOfMassTracking_ClassicalBackgroundSubtraction", "minPixelDiffForBackExtract": 20, "backgroundPreProcessParameters": [[3]], "backgroundPreProcessMethod": ["erodeThenMin"], "trackingPointSizeDisplay": 1, "nbAnimalsPerWell": 1, "extractAdvanceZebraParameters": 0, "trackTail": 0, "nbWells": 1, "noWellDetection": 1, "backgroundExtractionForceUseAllVideoFrames": 1, "headSize": 2, "createValidationVideo": 0, "lastFrame": 1000}
@@ -194,8 +198,9 @@ def morePreciseFastScreen(self, controller, nbRowsOfWells, nbWellsPerRows):
 
   self.configFile["nbRowsOfWells"] = int(nbRowsOfWells)
   self.configFile["nbWellsPerRows"] = int(nbWellsPerRows)
+  self.configFile["noBoutsDetection"] = int(not detectBouts)
 
-  self.calculateBackgroundFreelySwim(controller, 0, True)
+  self.calculateBackgroundFreelySwim(controller, 0, morePreciseFastScreen=True, boutDetectionsOnly=detectBouts)
 
   # controller.show_frame("FinishConfig")
 
@@ -266,7 +271,7 @@ def _chooseEnd(self, controller):
 
 def chooseBeginningAndEndOfVideo(self, controller):
   util.chooseBeginningPage(controller, controller.videoToCreateConfigFileFor, "Choose where the analysis of your video should start.", "Ok, I want the tracking to start at this frame!", lambda: _chooseEnd(self, controller),
-                           extraButtonInfo=("I want the tracking to run on the entire video!", lambda: _beginningAndEndChosen(self, controller), {"background_color": "greenyellow"}))
+                           extraButtonInfo=("I want the tracking to run on the entire video!", lambda: _beginningAndEndChosen(self, controller), {"background_color": util.DEFAULT_BUTTON_COLOR}))
 
 
 def getImageForMultipleAnimalGUI(l, nx, ny, max_l, videoToCreateConfigFileFor, background, wellPositions, hyperparameters):
@@ -419,45 +424,40 @@ def identifyMultipleHead(self, controller, nbanimals):
 
 
 @util.addToHistory
-def numberOfAnimals(self, controller, nbanimals, yes, noo, forceBlobMethodForHeadTracking, yesBouts, nooBouts, recommendedMethod, alternativeMethod, yesBends, nooBends, adjustBackgroundExtractionBasedOnNumberOfBlackPixels):
+def numberOfAnimals(nbanimals, animalsAlwaysVisible, forceBlobMethodForHeadTracking, detectBoutsMethod, recommendedMethod, calculateBends, adjustBackgroundExtractionBasedOnNumberOfBlackPixels):
+  app = QApplication.instance()
 
-  self.configFile["noBoutsDetection"] = 1
-  self.configFile["noChecksForBoutSelectionInExtractParams"] = 1
-  self.configFile["trackingPointSizeDisplay"] = 4
-  self.configFile["validationVideoPlotHeading"] = 0
+  app.configFile["noBoutsDetection"] = 1
+  app.configFile["noChecksForBoutSelectionInExtractParams"] = 1
+  app.configFile["trackingPointSizeDisplay"] = 4
+  app.configFile["validationVideoPlotHeading"] = 0
 
-  if int(yesBends):
-    self.configFile["extractAdvanceZebraParameters"] = 1
+  if calculateBends:
+    app.configFile["extractAdvanceZebraParameters"] = 1
 
-  nbanimals = int(nbanimals) if nbanimals is not None else self.configFile["nbWells"] * self.configFile["nbAnimalsPerWell"]
-  if nbanimals == self.configFile["nbWells"]:
-    self.configFile["nbAnimalsPerWell"] = 1
+  nbanimals = int(nbanimals) if nbanimals is not None else app.configFile["nbWells"] * app.configFile["nbAnimalsPerWell"]
+  if nbanimals == app.configFile["nbWells"]:
+    app.configFile["nbAnimalsPerWell"] = 1
   else:
-    self.configFile["nbAnimalsPerWell"] = int(nbanimals / self.configFile["nbWells"])
-    if noo:
-      self.configFile["multipleHeadTrackingIterativelyRelaxAreaCriteria"] = 0
-    else:
-      self.configFile["multipleHeadTrackingIterativelyRelaxAreaCriteria"] = 1
+    app.configFile["nbAnimalsPerWell"] = int(nbanimals / app.configFile["nbWells"])
+    app.configFile["multipleHeadTrackingIterativelyRelaxAreaCriteria"] = int(animalsAlwaysVisible)
 
-  self.forceBlobMethodForHeadTracking = int(forceBlobMethodForHeadTracking)
-  if self.forceBlobMethodForHeadTracking:
-    self.configFile["forceBlobMethodForHeadTracking"] = self.forceBlobMethodForHeadTracking
+  app.forceBlobMethodForHeadTracking = int(forceBlobMethodForHeadTracking)
+  if app.forceBlobMethodForHeadTracking:
+    app.configFile["forceBlobMethodForHeadTracking"] = app.forceBlobMethodForHeadTracking
 
-  if self.organism == 'zebrafish':
-    controller.show_frame("IdentifyHeadCenter")
-  elif self.organism == 'zebrafishNew':
-    detectBouts = 0
-    if int(yesBouts):
-      detectBouts = 1
-    method = 0
-    if int(alternativeMethod):
-      method = 1
-    automaticallyFindOptimalParameters(self, controller, True, detectBouts, method, int(noo), int(adjustBackgroundExtractionBasedOnNumberOfBlackPixels))
-  elif self.organism == 'drosoorrodent' and int(recommendedMethod):
-    automaticallyFindOptimalParameters(self, controller, True, 0, 0, int(noo), int(adjustBackgroundExtractionBasedOnNumberOfBlackPixels))
+  if app.organism == 'zebrafish':
+    app.show_frame("IdentifyHeadCenter")
+  elif app.organism == 'zebrafishNew':
+    automaticallyFindOptimalParameters(app, app, True, detectBoutsMethod, not recommendedMethod, not animalsAlwaysVisible, adjustBackgroundExtractionBasedOnNumberOfBlackPixels)
+    app.window.centralWidget().layout().currentWidget().refreshPage(showFasterTracking=not adjustBackgroundExtractionBasedOnNumberOfBlackPixels)
+  elif app.organism == 'drosoorrodent' and recommendedMethod:
+    automaticallyFindOptimalParameters(app, app, True, 0, False, not animalsAlwaysVisible, adjustBackgroundExtractionBasedOnNumberOfBlackPixels)
+    app.window.centralWidget().layout().currentWidget().refreshPage(showFasterTracking=not adjustBackgroundExtractionBasedOnNumberOfBlackPixels)
   else:
-    identifyMultipleHead(self, controller, nbanimals)
-    util.addToHistory(controller.show_frame)("FinishConfig")
+    identifyMultipleHead(app, app, nbanimals)
+    util.addToHistory(app.show_frame)("FinishConfig")
+    app.window.centralWidget().layout().currentWidget().refreshPage(showFasterTracking=not adjustBackgroundExtractionBasedOnNumberOfBlackPixels)
 
 
 @util.addToHistory
